@@ -1,9 +1,12 @@
-use strict; use warnings;
+use 5.008003; use strict; use warnings;
 package TestML::Tiny;
-our $VERSION = '0.0.11';
 
-use Carp;
-use Test::More;
+$TestML::Tiny::VERSION = 0.000001;
+
+use Carp();
+use Test::More 0.99 ();
+
+# use XXX;
 
 sub import {
     strict->import;
@@ -17,10 +20,9 @@ sub new {
     $self->{runtime} ||= TestML::Tiny::Runtime->new(
         bridge => $bridge,
     );
-    my $compiler = TestML::Tiny::Compiler->new(
+    $self->{function} ||= TestML::Tiny::Compiler->new(
         $self->{version} ? (version => $self->{version}) : (),
-    );
-    $self->{function} = $compiler->compile($testml);
+    )->compile($testml);
     return $self;
 }
 
@@ -62,8 +64,7 @@ sub _slurp {
 }
 
 #------------------------------------------------------------------------------
-=pod comment
-
+=comment
 ::Runtime -- Run a TestML Function
 
 The TestML Code and Data get compiled into a Function, and the Function is run
@@ -74,6 +75,8 @@ Test::More::is and Test::More::ok.
 
 package TestML::Tiny::Runtime;
 
+# use XXX;
+
 sub new {
     my $self = $TestML::Tiny::Runtime::Singleton =
         bless { @_[1..$#_] }, $_[0];
@@ -85,8 +88,7 @@ sub run {
 }
 
 #------------------------------------------------------------------------------
-=pod comment
-
+=comment
 ::Compiler -- Turn a TestML document into a runnable TestML Function.
 
 A TestML "document" is comprised of 3 main parts: Meta, Code, Data. This
@@ -107,13 +109,22 @@ the Runtime object.
 =cut
 package TestML::Tiny::Compiler;
 
+# use XXX;
+
 my $ID = qr/\w+/;
 my $SP = qr/[\ \t]/;
 my $LINE = qr/.*$/m;
 my $DIRECTIVE = qr/^%($ID)$SP+($LINE)/m;
 
 sub new {
-    my $self = bless { @_[1..$#_] }, $_[0];
+    my $self = bless {
+        code_syntax => 'tiny',
+        data_syntax => 'testml',
+        data_marker => '===',
+        block_marker => '===',
+        point_marker => '---',
+        @_[1..$#_]
+    }, $_[0];
 }
 
 sub runtime {
@@ -139,13 +150,6 @@ sub compile {
     return $function;
 }
 
-my %directives = (
-    code_syntax => 'tiny',
-    data_syntax => 'testml',
-    data_marker => '===',
-    block_marker => '===',
-    point_marker => '---',
-);
 sub preprocess {
     my ($self) = @_;
 
@@ -158,43 +162,22 @@ sub preprocess {
         if ($key eq "TestML") {
             $self->check_not_set_and_set($key, $value, 'version');
         }
-        elsif ($key eq "BlockMarker") {
-            $self->check_not_set_and_set(
-                'BlockMarker', $value, 'block_marker'
-            );
-            ($self->{block_marker} = $value) =~
-                s/([\*\^\$\+\?\(\)\.])/\\$1/g;
-        }
-        elsif ($key eq "PointMarker") {
-            $self->check_not_set_and_set(
-                'PointMarker', $value, 'point_marker'
-            );
-            ($self->{point_marker} = $value) =~
-                s/([\*\^\$\+\?\(\)\.])/\\$1/g;
-        }
         elsif ($key eq "CodeSyntax") {
             die "Untested";
-            $self->check_not_set_and_set(
-                'CodeSyntax', $value, 'code_syntax'
-            );
+            $self->check_not_set('CodeSyntax', $value, 'code_syntax');
+            $self->check_syntax($value);
             $self->{code_syntax} = $value;
         }
         elsif ($key eq "DataSyntax") {
             die "Untested";
-            $self->check_not_set_and_set(
-                'DataSyntax', $value, 'data_syntax'
-            );
+            $self->check_not_set('DataSyntax', $value, 'data_syntax');
+            $self->check_syntax($value);
             $self->{data_syntax} = $value;
         }
         else {
             Carp::croak "Unknown TestML directive: '%$key'";
         }
     }
-    $self->{data_marker} = $self->{block_marker}
-        if not($self->{data_marker}) and $self->{block_marker};
-    for my $directive (keys %directives) {
-        $self->{$directive} ||= $directives{$directive};
-    }
 
     ($self->{code}, $self->{data}) =
         ($testml =~ /(.*?)(^$self->{data_marker}.*)/msg);
@@ -238,9 +221,7 @@ sub compile_data_testml_0_1_0 {
     push @$lines, undef; # sentinel
     while (@$lines) {
         push @$parse, shift @$lines;
-        if (!defined($lines->[0]) or
-            $lines->[0] =~ /^$self->{block_marker}/
-        ) {
+        if ( !defined($lines->[0]) or $lines->[0] =~ /^===/ ) {
             my $block = $self->_parse_testml_block($parse);
             push @$blocks, $block
                 unless exists $block->{SKIP};
@@ -258,9 +239,8 @@ sub compile_data_testml_0_1_0 {
 sub _parse_testml_block {
     my ($self, $lines) = @_;
 
-    my ($label) = $lines->[0] =~ /^$self->{block_marker}(?:\s+(.*))?$/;
-    shift @$lines until not(@$lines) or
-        $lines->[0] =~ /^$self->{point_marker} +\w+/;
+    my ($label) = $lines->[0] =~ /^===(?:\s+(.*))?$/;
+    shift @$lines until not(@$lines) or $lines->[0] =~ /^--- +\w+/;
 
     my $block = $self->_parse_testml_points($lines);
     $block->{Label} = $label || '';
@@ -275,22 +255,21 @@ sub _parse_testml_points {
 
     while (@$lines) {
         my $line = shift @$lines;
-        $line =~ /^$self->{point_marker} +(\w+)/
+        $line =~ /^--- +(\w+)/
             or die "Invalid TestML line:\n'$line'";
         my $point_name = $1;
         die "$block repeats $point_name"
             if exists $block->{$point_name};
         $block->{$point_name} = '';
-        if ($line =~ /^$self->{point_marker} +(\w+): +(.*?) *$/) {
-            ($block->{$1} = $2) =~ s/^ *(.*?) *$/$1/;
-            shift @$lines while @$lines and
-                $lines->[0] !~ /^$self->{point_marker} +(\w)/;
+        if ($line =~ /^--- +(\w+): +(.*?) *$/) {
+            $block->{$1} .= "$2\n";
+            shift @$lines while @$lines and $lines->[0] !~ /^--- +(\w)/;
         }
-        elsif ($line =~ /^$self->{point_marker} +(\w+)$/) {
+        elsif ($line =~ /^--- +(\w+)$/) {
             $point_name = $1;
             while ( @$lines ) {
                 $line = shift @$lines;
-                if ($line =~ /^$self->{point_marker} \w+/) {
+                if ($line =~ /^--- \w+/) {
                     unshift @$lines, $line;
                     last;
                 }
@@ -307,8 +286,7 @@ sub _parse_testml_points {
 }
 
 #------------------------------------------------------------------------------
-=pod comment
-
+=comment
 A Function is just an array of "executable" statements that are proceseded in
 order. Some of the statements maybe be function declarations and function
 calls. The Compiler produces a top level scope function, with a Data set, and a
